import { EditorView } from '@codemirror/view';
import { HighlightStyle, syntaxHighlighting } from '@codemirror/language';
import { tags } from '@lezer/highlight';

const base00 = '#212121', base01 = '#505d64', base02 = '#606f7a', base03 = '#707d8b', base04 = '#a0a4ae', base05 = '#bdbdbd', base06 = '#e0e0e0', base07 = '#fdf6e3', base_red = '#ff5f52', base_deeporange = '#ff6e40', base_pink = '#fa5788', base_yellow = '#facf4e', base_orange = '#ffad42', base_cyan = '#56c8d8', base_indigo = '#7186f0', base_purple = '#cf6edf', base_green = '#6abf69', base_lightgreen = '#99d066', base_teal = '#4ebaaa';
const invalid = base_red, darkBackground = '#202325', highlightBackground = '#545b61', background = base00, tooltipBackground = base01, selection = base01, cursor = base04;
/// The editor theme styles for Material Dark.
const materialDarkTheme = /*@__PURE__*/EditorView.theme({
    '&': {
        color: base05,
        backgroundColor: background
    },
    '.cm-content': {
        caretColor: cursor
    },
    '.cm-cursor, .cm-dropCursor': { borderLeftColor: cursor },
    '&.cm-focused > .cm-scroller > .cm-selectionLayer .cm-selectionBackground, .cm-selectionBackground, .cm-content ::selection': { backgroundColor: selection },
    '.cm-panels': { backgroundColor: darkBackground, color: base03 },
    '.cm-panels.cm-panels-top': { borderBottom: '2px solid black' },
    '.cm-panels.cm-panels-bottom': { borderTop: '2px solid black' },
    '.cm-searchMatch': {
        outline: `1px solid ${base_yellow}`,
        backgroundColor: 'transparent'
    },
    '.cm-searchMatch.cm-searchMatch-selected': {
        backgroundColor: highlightBackground
    },
    '.cm-activeLine': { backgroundColor: highlightBackground },
    '.cm-selectionMatch': {
        backgroundColor: darkBackground,
        outline: `1px solid ${base_teal}`
    },
    '&.cm-focused .cm-matchingBracket': {
        color: base06,
        outline: `1px solid ${base_teal}`
    },
    '&.cm-focused .cm-nonmatchingBracket': {
        color: base_red
    },
    '.cm-gutters': {
        backgroundColor: base00,
        borderRight: '1px solid #4f5b66',
        color: base02
    },
    '.cm-activeLineGutter': {
        backgroundColor: highlightBackground,
        color: base07
    },
    '.cm-foldPlaceholder': {
        backgroundColor: 'transparent',
        border: 'none',
        color: '#ddd'
    },
    '.cm-tooltip': {
        border: 'none',
        backgroundColor: tooltipBackground
    },
    '.cm-tooltip .cm-tooltip-arrow:before': {
        borderTopColor: 'transparent',
        borderBottomColor: 'transparent'
    },
    '.cm-tooltip .cm-tooltip-arrow:after': {
        borderTopColor: tooltipBackground,
        borderBottomColor: tooltipBackground
    },
    '.cm-tooltip-autocomplete': {
        '& > ul > li[aria-selected]': {
            backgroundColor: highlightBackground,
            color: base03
        }
    }
}, { dark: true });
/// The highlighting style for code in the Material Dark theme.
const materialDarkHighlightStyle = /*@__PURE__*/HighlightStyle.define([
    { tag: tags.keyword, color: base_purple },
    {
        tag: [tags.name, tags.deleted, tags.character, tags.macroName],
        color: base_cyan
    },
    { tag: [tags.propertyName], color: base_yellow },
    { tag: [tags.variableName], color: base05 },
    { tag: [/*@__PURE__*/tags.function(tags.variableName)], color: base_cyan },
    { tag: [tags.labelName], color: base_purple },
    {
        tag: [tags.color, /*@__PURE__*/tags.constant(tags.name), /*@__PURE__*/tags.standard(tags.name)],
        color: base_yellow
    },
    { tag: [/*@__PURE__*/tags.definition(tags.name), tags.separator], color: base_pink },
    { tag: [tags.brace], color: base_purple },
    {
        tag: [tags.annotation],
        color: invalid
    },
    {
        tag: [tags.number, tags.changed, tags.annotation, tags.modifier, tags.self, tags.namespace],
        color: base_orange
    },
    {
        tag: [tags.typeName, tags.className],
        color: base_orange
    },
    {
        tag: [tags.operator, tags.operatorKeyword],
        color: base_indigo
    },
    {
        tag: [tags.tagName],
        color: base_deeporange
    },
    {
        tag: [tags.squareBracket],
        color: base_red
    },
    {
        tag: [tags.angleBracket],
        color: base02
    },
    {
        tag: [tags.attributeName],
        color: base05
    },
    {
        tag: [tags.regexp],
        color: invalid
    },
    {
        tag: [tags.quote],
        color: base_green
    },
    { tag: [tags.string], color: base_lightgreen },
    {
        tag: tags.link,
        color: base_cyan,
        textDecoration: 'underline',
        textUnderlinePosition: 'under'
    },
    {
        tag: [tags.url, tags.escape, /*@__PURE__*/tags.special(tags.string)],
        color: base_yellow
    },
    { tag: [tags.meta], color: base03 },
    { tag: [tags.comment], color: base03, fontStyle: 'italic' },
    { tag: tags.monospace, color: base05 },
    { tag: tags.strong, fontWeight: 'bold', color: base_red },
    { tag: tags.emphasis, fontStyle: 'italic', color: base_lightgreen },
    { tag: tags.strikethrough, textDecoration: 'line-through' },
    { tag: tags.heading, fontWeight: 'bold', color: base_yellow },
    { tag: tags.heading1, fontWeight: 'bold', color: base_yellow },
    {
        tag: [tags.heading2, tags.heading3, tags.heading4],
        fontWeight: 'bold',
        color: base_yellow
    },
    {
        tag: [tags.heading5, tags.heading6],
        color: base_yellow
    },
    { tag: [tags.atom, tags.bool, /*@__PURE__*/tags.special(tags.variableName)], color: base_cyan },
    {
        tag: [tags.processingInstruction, tags.inserted],
        color: base_red
    },
    {
        tag: [tags.contentSeparator],
        color: base_cyan
    },
    { tag: tags.invalid, color: base02, borderBottom: `1px dotted ${base_red}` }
]);
/// Extension to enable the Material Dark theme (both the editor theme and
/// the highlight style).
const materialDark = [
    materialDarkTheme,
    /*@__PURE__*/syntaxHighlighting(materialDarkHighlightStyle)
];

export { materialDark, materialDarkHighlightStyle, materialDarkTheme };
